==> kdevplatform-1.0.80.tar.bz2: kdevplatform-1.0.80/vcs/widgets/standardvcslocationwidget.h <==
/* KDevPlatform Vcs Support
 *
 * Copyright 2010 Aleix Pol <aleixpol@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef STANDARDVCSLOCATIONWIDGET_H
#define STANDARDVCSLOCATIONWIDGET_H

#include <vcs/widgets/vcslocationwidget.h>
#include "../vcsexport.h"

class KUrl;
class KUrlRequester;
namespace KDevelop
{

class KDEVPLATFORMVCS_EXPORT StandardVcsLocationWidget : public VcsLocationWidget
{
    Q_OBJECT
    public:
        StandardVcsLocationWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);
        virtual VcsLocation location() const;
        virtual bool isCorrect() const;
        KUrl url() const;
        virtual QString projectName() const;
        
    public slots:
        void textChanged(const QString& str);
        
    private:
        KUrlRequester* m_urlWidget;
};

}
#endif // STANDARDVCSLOCATIONWIDGET_H

==> kdevplatform-1.7.3.tar.bz2: kdevplatform-1.7.3/vcs/widgets/standardvcslocationwidget.h <==
/* KDevPlatform Vcs Support
 *
 * Copyright 2010 Aleix Pol <aleixpol@gmail.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301, USA.
 */

#ifndef KDEVPLATFORM_STANDARDVCSLOCATIONWIDGET_H
#define KDEVPLATFORM_STANDARDVCSLOCATIONWIDGET_H

#include <vcs/widgets/vcslocationwidget.h>
#include "../vcsexport.h"

class KUrl;
class KUrlRequester;
namespace KDevelop
{

class KDEVPLATFORMVCS_EXPORT StandardVcsLocationWidget : public VcsLocationWidget
{
    Q_OBJECT
    public:
        StandardVcsLocationWidget(QWidget* parent = 0, Qt::WindowFlags f = 0);
        virtual VcsLocation location() const;
        virtual bool isCorrect() const;
        KUrl url() const;
        virtual QString projectName() const;
        
    public slots:
        void textChanged(const QString& str);
        
    private:
        KUrlRequester* m_urlWidget;
};

}
#endif // KDEVPLATFORM_STANDARDVCSLOCATIONWIDGET_H
